<template>
  <div class="tree-table-container">
    <div class="box" ref="box">
      <div class="left">
        <!--左侧div内容-->
        <div class="common-tree-container">
          <div class="common-tree-title">
            <i class="el-icon-menu" /> 组织目录
          </div>
          <div class="common-tree-content">
            <el-tree highlight-current :data="orgTreeList" :props="defaultProps" default-expand-all
              :expand-on-click-node="false" @node-click="handleNodeClick" />
          </div>
        </div>
      </div>
      <div class="resize" title="收缩侧边栏">
        ⋮
      </div>
      <div class="mid">
        <!--右侧div内容-->
        <div class="common-table-container">
          <div class="bbsl-common-page">
            <div class="bbsl-table-search">
              <el-form v-model="queryParam" label-width="auto">
                <el-row :gutter="10">
                  <el-col :span="6">
                    <el-form-item label="小组编号">
                      <el-input v-model="querys[0].value" clearable  placeholder="请输入小组编号" />
                    </el-form-item>
                  </el-col>
                  <el-col :span="6">
                    <el-form-item label="小组名称">
                      <el-input v-model="querys[1].value" clearable placeholder="请输入小组名称" />
                    </el-form-item>
                  </el-col>
                  <el-col :span="6">
                    <el-form-item label="负责区域">
                      <el-input v-model="querys[2].value" clearable placeholder="请输入负责区域" />
                    </el-form-item>
                  </el-col>
                  <el-col :span="4">
                    <el-button type="primary" icon="el-icon-search" @click="handleSearch">搜索</el-button>
                    <el-button icon="el-icon-refresh" @click="handleReset">重置</el-button>
                  </el-col>
                </el-row>
              </el-form>
            </div>
            <div ref="contentPanel" class="bbsl-table-content">
              <div ref="btnPanel" class="bbsl-btn-content">
                <el-button icon="el-icon-plus" type="primary" @click="handleAdd">新增</el-button>
                <el-popconfirm title="确定删除选中数据吗？" @confirm="handleDelete">
                  <el-button slot="reference" :disabled="!multipleSelection.length" icon="el-icon-delete" type="danger"
                    style="margin-left: 10px">删除</el-button>
                </el-popconfirm>
              </div>
              <el-table ref="multipleSelection" v-loading="loading" border size="mini" :data="tableData"
                :style="{ width: '100%' }" :max-height="tableMaxHeight" :cell-style="{ 'text-align': 'center' }"
                :header-cell-style="{ 'text-align': 'center' }" @row-dblclick="handleDbClick"
                @selection-change="handleSelectionChange">
                <el-table-column type="selection" width="55" />
                <el-table-column type="index" width="55" label="序号" />
                <el-table-column prop="code" label="组编号" show-overflow-tooltip />
                <el-table-column prop="name" label="组名称" show-overflow-tooltip />
                <el-table-column prop="alias" label="组别名" show-overflow-tooltip />
                <el-table-column prop="headman" label="负责人" show-overflow-tooltip />
                <el-table-column prop="area" label="负责区域" show-overflow-tooltip />
                <el-table-column prop="orgName" label="归属部门" show-overflow-tooltip />
                <el-table-column prop="createTime" label="创建时间" width="155" show-overflow-tooltip />
              </el-table>
              <el-pagination ref="paginationPanel" align="right" background class="bbsl-pagination"
                :current-page="queryParam.pageBean.page" :page-sizes="[20, 30, 40, 50]"
                :page-size="queryParam.pageBean.pageSize" layout="total, sizes, prev, pager, next, jumper"
                :total="total" @size-change="handleSizeChange" @current-change="handleCurrentChange" />
            </div>
          </div>
        </div>
      </div>
    </div>
    <el-row class="fullheight">
      <el-col :span="4" class="fullheight"> </el-col>
      <el-col :span="20" class="fullheight"> </el-col>
    </el-row>
    <team-manage-dialog ref="formModal" />
  </div>
</template>

<script>
import { dragControllerDiv } from '../material/api/dragControllerDiv'
import { TableMixin } from '@/mixins/tableMixin'
import TeamManage from '@/api/manager/duty/teamManage.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'
import TeamManageDialog from '@/views/Manage/duty/components/TeamManageDialog'
import dictContracts from '@/components/dict/DictSelectUtils.js'
import CommonApi from '@/views/Manage/CommonApi.js'
export default {
  name: 'TeamManage',
  components: {
    TeamManageDialog
  },
  mixins: [TableMixin],
  data() {
    return {
      url: {
        delete: '/manager/duty/team/'
      },
      querys: [
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'code_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'name_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'LIKE',
          parentGroup: '',
          property: 'area_',
          relation: 'AND',
          value: ''
        },
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'org_id_',
          relation: 'AND',
          value: '',
          label: ''
        }
      ],
      defaultProps: {
        value: 'id',
        label: 'name',
        parentId: 'parentId',
        code: 'code',
        children: 'children'
      },
      StshowFormDias: false,
      orgTreeList: []
    }
  },
  created() {
    this.loadOrg()
  },
  mounted() {
    dragControllerDiv()
  },
  methods: {
    // 重置
    clearQuerys() {
      this.querys[0].value = ''
      this.querys[1].value = ''
      this.querys[2].value = ''
      this.querys[3].value = ''
    },
    loadOrg() {
      //   CommonApi.loadSelectOptions({ name: 'manageCommonService.findZGJOrg' }, res => {
      //     this.orgTreeList = res
      //   })
      CommonApi.getAllOrgTree(res => {
        this.orgTreeList = res.data
      })
    },
    loadData(page) {
      // 获取list
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.sorter = [
        {
          direction: 'ASC',
          property: 'sn_'
        }
      ]
      this.queryParam.querys = []
      if (this.querys[0].value) {
        this.queryParam.querys.push(this.querys[0])
      }
      if (this.querys[1].value) {
        this.queryParam.querys.push(this.querys[1])
      }
      if (this.querys[2].value) {
        this.queryParam.querys.push(this.querys[2])
      }
      if (this.querys[3].value) {
        this.queryParam.querys.push(this.querys[3])
      }
      TeamManage.loadTeam(this.queryParam, res => {
        this.total = res.total
        this.tableData = res.rows
        this.$set(this.tableData)
        this.loading = false
      })
    },

    handleAdd() {
      if (!this.querys[3].value) {
        this.$message.warning('请选择所属的组织部门！')
        return
      }
      this.$refs.formModal.add(this.querys[3])
    },

    handleUpdate(row) {
      console.log(row.id)
      this.$refs.formModal.Update(row)
    },
    closeStshowForm() {
      this.StshowFormDias = false
    },
    handleNodeClick(data) {
      // 点击分类树节点
      this.querys[3].value = data.id
      this.querys[3].label = data.name
      this.loadData(1)
    }
  }
}
</script>
<style scoped>
/* 拖拽相关样式 */
/*包围div样式*/
.box {
  width: 100%;
  height: 100%;
  /* margin: 10px 0px; */
  overflow: hidden;
  box-shadow: -1px 9px 10px 3px rgba(0, 0, 0, 0.11);
}

/*左侧div样式*/
.left {
  width: calc(16% - 10px);
  /*左侧初始化宽度*/
  height: 100%;
  background: #ffffff;
  float: left;
}

/*拖拽区div样式*/
.resize {
  cursor: col-resize;
  float: left;
  position: relative;
  top: 45%;
  background-color: #d6d6d6;
  border-radius: 5px;
  margin-top: -10px;
  width: 10px;
  height: 50px;
  background-size: cover;
  background-position: center;
  /*z-index: 99999;*/
  font-size: 32px;
  color: white;
}

/*拖拽区鼠标悬停样式*/
.resize:hover {
  color: #444444;
}

/*右侧div'样式*/
.mid {
  float: left;
  width: 84%;
  /*右侧初始化宽度*/
  height: 100%;
  background: #fff;
  box-shadow: -1px 4px 5px 3px rgba(0, 0, 0, 0.11);
}
</style>
<style lang="scss" scoped>
.step-container {
  width: 80%;
  margin: 0 auto 20px;
}

.dialog-footer {
  text-align: center;
}
</style>
<style lang="scss" scoped>
.type-tag {
  margin: 0 2px;
}
</style>
